/***************************************************************************
 *   Copyright (C) 2010 by Vladimir Jary                                   *
 *   <Vladimir.Jary@cern.ch>                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/***************************************************************************
 *                            _              _                ___   _      *
 *       ___ _ __   ___      | |_ ___   ___ | |___  __   __  / _ \ / |     *
 *      / __| '_ \ / _ \_____| __/ _ \ / _ \| / __| \ \ / / | | | || |     *
 *      \__ \ |_) |  __/_____| || (_) | (_) | \__ \  \ V /  | |_| || |     *
 *      |___/ .__/ \___|      \__\___/ \___/|_|___/   \_/    \___(_)_|     *
 *          |_|                                                            *
 *                                                                         *
 *      (21. 2. 2010)                                                      *
 *                                                                         *
 * This program converts SPE files produced by Princeton Instruments CCD   *
 * camera into open formats:                                               *
 * 1. plain text (*.txt files)                                             *
 * 2. comma-separated values spreadsheet (*.csv files)                     *
 * 3. portable graymap (*.pgm files)                                       *
 *                                                                         *
 * Usage:                                                                  *
 * spe-tools input.spe <format>                                            *
 * format is one of the following: txt, csv, pgm                           *
 *                                                                         *
 * Limitations:                                                            *
 * Program currently supports only spe files which contain data stored     *
 * as 16-bit unsigned integer (_should_ be the case of SPE files produced  *
 * by OSQAR experiment)                                                    *
 *                                                                         *
 * External links:                                                         *
 * SPE header: http://rsb.info.nih.gov/ij/plugins/spe.html                 *
 ***************************************************************************/

#include <QtCore/QCoreApplication>
#include <QtCore/QFile>
#include <QtCore/QDataStream>
#include <QtCore/QTextStream>
#include <QtCore/QString>
#include <iostream>


#include "speexporter.h"

void printHelp()
{
    {
        qDebug("                      _              _");
        qDebug(" ___ _ __   ___      | |_ ___   ___ | |___");
        qDebug("/ __| '_ \\ / _ \\_____| __/ _ \\ / _ \\| / __|");
        qDebug("\\__ \\ |_) |  __/_____| || (_) | (_) | \\__ \\ ");
        qDebug("|___/ .__/ \\___|      \\__\\___/ \\___/|_|___/");
        qDebug("    |_|");

        qDebug("v 0.1 (21. 2. 2010)");
        qDebug("Converts spe files produced by Princeton Instruments CCD camera");
        qDebug("into plain text, comma-separated values spreadsheet, or portable graymap");
        qDebug("written by Vladimir Jary <Vladimir.Jary@cern.ch>");

        qDebug(" ");
        qDebug("Usage: spe-tools file.spe <format>");
        qDebug("where <format> is one of the following: txt, csv, pgm");
    }
}

int main(int argc, char *argv[])
{
    //QCoreApplication a(argc, argv);

    if(argc != 3)
    {
        printHelp();
        return -1;
    }

    SpeExporter exporter(argv[1]);

    QString format = argv[2];
    format = format.toLower();

    if(format == "txt")
        exporter.export2txt();
    else if(format == "csv")
        exporter.export2csv();
    else if(format == "pgm")
        exporter.export2pgm();
    else
    {
        printHelp();
        return -1;
    }



    return 0;
    //return a.exec();
}
